==> mingw-w64-qgis-3.44.1-2.src.tar.zst: qgis-3.44.1/src/core/pointcloud/qgspointcloudrequest.cpp <==
/***************************************************************************
                         qgspointcloudrequest.cpp
                         -----------------------
    begin                : October 2020
    copyright            : (C) 2020 by Peter Petrik
    email                : zilolv at gmail dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qgis.h"
#include "qgspointcloudrequest.h"
#include "qgspointcloudattribute.h"

QgsPointCloudRequest::QgsPointCloudRequest() = default;

bool QgsPointCloudRequest::operator==( const QgsPointCloudRequest &other ) const
{
  return mIgnoreIndexFilter == other.ignoreIndexFilterEnabled() &&
         mFilterRect == other.filterRect() &&
         mAttributes.toFields() == other.attributes().toFields();
}

QgsPointCloudAttributeCollection QgsPointCloudRequest::attributes() const
{
  return mAttributes;
}

void QgsPointCloudRequest::setAttributes( const QgsPointCloudAttributeCollection &attributes )
{
  mAttributes = attributes;
}

uint qHash( const QgsPointCloudRequest &request )
{
  return qHash( request.filterRect() ) ^ qHash( request.attributes().pointRecordSize() ) ^ request.ignoreIndexFilterEnabled();
}

==> mingw-w64-qgis-3.44.3-2.src.tar.zst: qgis-3.44.3/src/core/pointcloud/qgspointcloudrequest.cpp <==
/***************************************************************************
                         qgspointcloudrequest.cpp
                         -----------------------
    begin                : October 2020
    copyright            : (C) 2020 by Peter Petrik
    email                : zilolv at gmail dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "qgis.h"
#include "qgspointcloudrequest.h"
#include "qgspointcloudattribute.h"

QgsPointCloudRequest::QgsPointCloudRequest() = default;

bool QgsPointCloudRequest::operator==( const QgsPointCloudRequest &other ) const
{
  return mIgnoreIndexFilter == other.ignoreIndexFilterEnabled() &&
         mFilterRect == other.filterRect() &&
         mAttributes.toFields() == other.attributes().toFields();
}

QgsPointCloudAttributeCollection QgsPointCloudRequest::attributes() const
{
  return mAttributes;
}

void QgsPointCloudRequest::setAttributes( const QgsPointCloudAttributeCollection &attributes )
{
  mAttributes = attributes;
}

uint qHash( const QgsPointCloudRequest &request )
{
  return qHash( request.filterRect() ) ^ qHash( request.attributes().pointRecordSize() ) ^ ( request.ignoreIndexFilterEnabled() ? 0 : 1 );
}
